@@ -283,6 +283,11 @@ class ServiceClient():
     def prepare_json(self, parameters):
         return(self.__class__._prepare_json(parameters, object=self))
 
+    @property
+    def default_service(self):
+        #TODO: we either needto change the class variables to 'api' and 'api_version' or handle instance variables here.
+        return(self.get_service(self.default_api, self.default_api_version))
+
     @classmethod
     def get_service(cls, api=None, api_version=None):
         if api:
